==============================
Natural Language Qu Kit (NLQK)
==============================

(C) 2024-2025 by `Damir Cavar`_, `NLP-Lab`_

Natural Language Qu Kit (NLQK) is a Quantum Natural Language Processing (Q-NLP) library.

See for more details the `Natural Language Processing Lab`_ (`NLP-Lab`_) and the `Quantum NLP Group <https://nlp-lab.org/quantumnlp/>`_.


- Documentation
- `GitHub repo <https://github.com/dcavar/nlqk>`_
- `PyPi page <https://pypi.org/project/nlqk/>`_


Contributors
================
- `Damir Cavar`_ (main author, maintainer, project lead)
- `Koushik Reddy Parukola`_
- `Shane A. Sparks`_
- `James B. Graves`_

.. _Damir Cavar: http://damir.cavar.me/
.. _Koushik Reddy Parukola: https://www.linkedin.com/in/koushik-reddy-parukola/
.. _Shane A. Sparks: https://
.. _James B. Graves: https://
.. _NLP-Lab: https://nlp-lab.org/
.. _Natural Language Processing Lab: https://nlp-lab.org/
